@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 1146 2021-07-15 10:23:49Z Lavender $
+# $Id: __init__.py 1129 2021-07-09 07:36:53Z Casey $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2021-07-15 18:23:49 +0800 (週四, 15 七月 2021) $
-# $Revision: 1146 $
+# $Author: Casey $ (last)
+# $Date: 2021-07-09 15:36:53 +0800 (Fri, 09 Jul 2021) $
+# $Revision: 1129 $
 
 import os
 import sys
@@ -167,7 +167,7 @@ def record(func, c, *args, **kwargs):
 
 # patch
 @opens
-def run(self, command, notRecord=False, hideStdout=False, **kwargs):
+def run(self, command, notRecord=False, **kwargs):
     """
     Execute a shell command on the remote end of this connection.
 
@@ -193,9 +193,6 @@ def run(self, command, notRecord=False, hideStdout=False, **kwargs):
 
     if six.PY2 and not kwargs.get("pty"):
         kwargs["hide"] = True
-        
-    if hideStdout:
-        kwargs["hide"] = True
 
     if not notRecord:
         c = "%s: %s" % (command, str(datetime.datetime.now().time()))
